easycrypt

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 10, 2024 License: Unlicense Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Decrypt

func Decrypt(key, cryptoText string) (string, error)

Decrypt decrypts the given base64 encoded ciphertext using AES encryption with the provided passphrase

func Encrypt

func Encrypt(key, plaintext string) (string, error)

Encrypt encrypts the given plaintext using AES encryption with the provided passphrase

Types

This section is empty.

Directories

Path Synopsis
Package easycrypt provides simple functions for encrypting and decrypting text using AES encryption.
Package easycrypt provides simple functions for encrypting and decrypting text using AES encryption.
Package main demonstrates how to use the easycrypt package to encrypt and decrypt text.
Package main demonstrates how to use the easycrypt package to encrypt and decrypt text.

Jump to